otcextensions.sdk.anti_ddos.v1.config
=====================================

.. automodule:: otcextensions.sdk.anti_ddos.v1.config

The Anti DDoS Config Class
--------------------------

The ``Config`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.anti_ddos.v1.config.Config
   :members:
